#[derive(Cli)]
{
// Attributes available to this derive:
#[usage]
#[command]
#[arg]
#[value]
#[group]
}
Compile a struct into a parser and a spec. See the crate docs.
#[derive(Cli)]
{
// Attributes available to this derive:
#[usage]
#[command]
#[arg]
#[value]
#[group]
}
Compile a struct into a parser and a spec. See the crate docs.