pub enum Outcome<T> {
Parsed(T),
Exit(Exit),
}Expand description
The two things dispatching a CLI inside another runtime can do.
Variants
Parsed(T)
The command line parsed and the host can run it.
Exit(Exit)
The host should print a response and return its status without running the command.
Implementations