pub fn invalid_choice_value<'t, 'v>(
name: &'t str,
value: String,
) -> Error<'t, 'v>Expand description
One Error::InvalidValue for a word that is not one of a value enum’s choices.
pub fn invalid_choice_value<'t, 'v>(
name: &'t str,
value: String,
) -> Error<'t, 'v>One Error::InvalidValue for a word that is not one of a value enum’s choices.