pub struct CommandOverlay<'a> {
pub command: CommandSelector<'a>,
pub effect: Effect,
}Expand description
One sparse metadata override applied by SpecView.
This deliberately contains only properties with real fleet users. Adding a property is preferable to exposing a mutable command builder: the base derive tables remain immutable, shareable and free to parse.
Fields
command: CommandSelector<'a>effect: EffectImplementations
Sourceimpl<'a> CommandOverlay<'a>
impl<'a> CommandOverlay<'a>
pub const fn effect(path: &'a str, effect: Effect) -> CommandOverlay<'a>
pub const fn effect_for(key: u64, effect: Effect) -> CommandOverlay<'a>